starcluster.tests.test_config.TestStarClusterConfig

Package starcluster :: Package tests :: Module test_config :: Class TestStarClusterConfig |
[hide private]
[frames] | no frames]

# Class TestStarClusterConfig

source code

Nested Classes | [hide private]
Inherited from `unittest.TestCase`: `failureException`

Instance Methods | [hide private]
test_valid_config_template(self) | source code
test_config_dne(self) | source code
test_get_cluster(self) | source code
test_int_required(self) | source code
test_bool_required(self) | source code
test_missing_required(self) | source code
test_volumes(self) | source code
test_volume_not_defined(self) | source code
test_clusters(self) | source code
test_extends(self) | source code
test_order_invariance(self) Loads all cluster sections in the test config in all possible orders (ie c1,c2,c3, c3,c1,c2, etc) and test that the results are the same | source code
test_plugins(self) | source code
test_plugin_not_defined(self) | source code
test_keypairs(self) | source code
test_keypair_not_defined(self) | source code
test_invalid_config(self) Test that reading a non-INI formatted file raises an exception | source code
test_empty_config(self) Test that reading an empty config generates no errors and that aws credentials can be read from the environment. | source code
test_cyclical_extends(self) Test that cyclical extends in the config raises an exception | source code
test_choices(self) Test that config enforces a value to be one of a list of choices if specified | source code
test_multiple_instance_types(self) Test that config properly handles multiple instance types syntax (within node_instance_type setting) | source code
Inherited from `StarClusterTest`: `get_config`, `get_custom_config` Inherited from `unittest.TestCase`: `__call__`, `__eq__`, `__hash__`, `__init__`, `__ne__`, `__repr__`, `__str__`, `assertAlmostEqual`, `assertAlmostEquals`, `assertEqual`, `assertEquals`, `assertFalse`, `assertNotAlmostEqual`, `assertNotAlmostEquals`, `assertNotEqual`, `assertNotEquals`, `assertRaises`, `assertTrue`, `assert_`, `countTestCases`, `debug`, `defaultTestResult`, `fail`, `failIf`, `failIfAlmostEqual`, `failIfEqual`, `failUnless`, `failUnlessAlmostEqual`, `failUnlessEqual`, `failUnlessRaises`, `id`, `run`, `setUp`, `shortDescription`, `tearDown` Inherited from `unittest.TestCase` (private): `_exc_info` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
Inherited from `StarClusterTest`: `config` Inherited from `object`: `__class__`